from anna_lib.task.abstract_task import AbstractTask


class SwitchTo(AbstractTask):
	def __execute__(self):
		self.switch_to('#test-switch-to')

	def after_execute(self):
		self.result.append({'passed': True})



from anna_lib.task.abstract_task import AbstractTask


class Submit(AbstractTask):
	def before_execute(self):
		self.timeout = 1

	def __execute__(self):
		self.scroll_to('#iframe-test-submit')
		self.submit('#iframe-test-submit')

	def after_execute(self):
		self._assert('element_exists', '.iframe-submitted')



from anna_lib.task.abstract_task import AbstractTask


class Select(AbstractTask):
	def __execute__(self):
		self.click('$xpath//select[@name="xpath"]/option[@value="option"]')

	def after_execute(self):
		self.result.append({'passed': True})



from anna_lib.task.abstract_task import AbstractTask


class Wait(AbstractTask):
	def __execute__(self):
		self.click('#test-wait')
		self.wait('#test-wait-get')

	def after_execute(self):
		self._assert('element_exists', '#test-wait-get')



from anna_lib.task.abstract_task import AbstractTask


class Click(AbstractTask):
	def __execute__(self):
		self.click('#test-click')

	def after_execute(self):
		self._assert('element_exists', '.clicked')



from anna_lib.task.abstract_task import AbstractTask


class CurrentUrl(AbstractTask):
	def __execute__(self):
		self.click('#test-current-url')

	def after_execute(self):
		self._assert('in_url', 'test/switchto')



from anna_lib.task.abstract_task import AbstractTask


class Hover(AbstractTask):
	def __execute__(self):
		self.hover('#test-hover')

	def after_execute(self):
		self._assert('element_exists', '.hovered')



from anna_lib.task.abstract_task import AbstractTask


class Click(AbstractTask):
    def before_execute(self):
        self.timeout = 1

    def __execute__(self):
        self.scroll_to('#iframe-test-click')
        self.click('#iframe-test-click')

    def after_execute(self):
        self._assert('element_exists', '.iframe-clicked')



from anna_lib.task.abstract_task import AbstractTask


class SendKeys(AbstractTask):
	def before_execute(self):
		self.timeout = 1

	def __execute__(self):
		self.scroll_to('#iframe-test-send-keys')
		self.send_keys(target='#iframe-test-send-keys', value='iframe_test_send_keys')

	def after_execute(self):
		self._assert('element_exists', '.iframe_test_send_keys')



import setuptools

description = "### anna tasks package"

setuptools.setup(
	name='anna_unittasks',
	version='1.0.13',
	author='Patrik Pihlstrom',
	author_email='patrik.pihlstrom@gmail.com',
	url='https://github.com/patrikpihlstrom/anna-unittasks',
	description='anna task package for unittesting',
	long_description=description,
	long_description_content_type='text/markdown',
	install_requires=['anna-lib'],
	packages=['anna_unittasks', 'anna_unittasks.iframe']
)



from anna_lib.task.abstract_task import AbstractTask


class Wait(AbstractTask):
	def before_execute(self):
		self.timeout = 5

	def __execute__(self):
		self.scroll_to('#iframe-test-wait')
		self.click('#iframe-test-wait')
		self.wait('#iframe-test-wait-get')

	def after_execute(self):
		self._assert('element_exists', '#iframe-test-wait-get')



url = "https://test.annahub.dev/"
sequence = (
	"send_keys",
	"submit",
	"click",
	"hover",
	"wait",
	"select",
	"switch_to",
	"iframe.send_keys",
	"iframe.submit",
	"iframe.click",
	"iframe.hover",
	"iframe.wait"
)



from anna_lib.task.abstract_task import AbstractTask


class SendKeys(AbstractTask):
	def __execute__(self):
		self.send_keys(target='#test-send-keys', value='test_send_keys')

	def after_execute(self):
		self._assert('element_exists', '.test_send_keys')
